==> mongodb-ui-components-4.0.19.tgz: package/src/nav/js/nav-icons.js <==
const React = require('react')

const contactIcon =
  <svg width='18px' height='18px' viewBox='0 0 32 32' fill='#9E9E9E'><path d='M2.13 1.19c1.28-1.28 5.14-1.49 5.17-0.82 0.03 0.68 3.48 8.19 3.51 8.87s-2.27 2.99-2.95 3.66c-0.67 0.67 4.51 6.53 4.61 6.64 0.11 0.1 5.96 5.29 6.63 4.62 0.67-0.68 2.98-2.98 3.65-2.95 0.68 0.03 8.17 3.49 8.85 3.52 0.68 0.03 0.46 3.9-0.81 5.18-1.09 1.1-6.75 5.07-16.59-2.03-1.08-0.62-2.79-2.05-5.38-4.65 0 0 0 0 0 0 0 0 0 0-0.01-0.01s0 0-0.01-0.01c0 0 0 0 0 0-2.59-2.6-4.01-4.31-4.63-5.39-7.08-9.86-3.12-15.54-2.02-16.63z' /></svg>

const searchIcon =
  <svg width='21px' height='21px' viewBox='0 0 24 24' fill='#9E9E9E'><path d='M21.7 20.3l-4.5-4.5c1.1-1.4 1.8-3.3 1.8-5.3 0-4.7-3.8-8.5-8.5-8.5s-8.5 3.8-8.5 8.5c0 4.7 3.8 8.5 8.5 8.5 2 0 3.8-0.7 5.3-1.8l4.5 4.5c0.2 0.2 0.5 0.3 0.7 0.3s0.5-0.1 0.7-0.3c0.4-0.4 0.4-1 0-1.4zM4 10.5c0-3.6 2.9-6.5 6.5-6.5s6.5 2.9 6.5 6.5c0 1.8-0.7 3.4-1.9 4.6 0 0 0 0 0 0s0 0 0 0c-1.2 1.2-2.8 1.9-4.6 1.9-3.6 0-6.5-2.9-6.5-6.5z' /></svg>

const downloadIcon = (
  <svg width='14px' height='21px' viewBox='0 0 16 21'>
    <g stroke='none' strokeWidth='1' fill='none' fillRule='evenodd'>
      <g transform='translate(-1282.000000, -16.000000)' fill='#FFFFFF'>
        <g transform='translate(0.000000, -1.000000)'>
          <g transform='translate(85.000000, 0.000000)'>
            <g transform='translate(1197.000000, 17.000000)'>
              <path d='M13.9079108,6.9539554 L13.0386664,6.9539554 L13.0386664,8.69244425 L13.9079108,8.69244425 L13.9079108,13.9079108 L1.73848885,13.9079108 L1.73848885,8.69244425 L2.60773328,8.69244425 L2.60773328,6.9539554 L1.73848885,6.9539554 C0.77971225,6.9539554 0,7.73366765 0,8.69244425 L0,16.5156441 C0,17.4744207 0.77971225,18.2541329 1.73848885,18.2541329 L6.9539554,18.2541329 L6.9539554,19.1233774 L4.34622213,19.1233774 L4.34622213,20.8618662 L11.3001775,20.8618662 L11.3001775,19.1233774 L8.69244425,19.1233774 L8.69244425,18.2541329 L13.9079108,18.2541329 C14.8666874,18.2541329 15.6463997,17.4744207 15.6463997,16.5156441 L15.6463997,8.69244425 C15.6463997,7.73366765 14.8666874,6.9539554 13.9079108,6.9539554 L13.9079108,6.9539554 Z' />
              <path d='M11.9147333,6.69926679 L10.6856217,5.47015517 L8.69244425,7.46333264 L8.69244425,0 L6.9539554,0 L6.9539554,7.46333264 L4.96077794,5.47015517 L3.73166632,6.69926679 L7.82319983,10.7908003 L11.9147333,6.69926679 Z' id='Shape' />
            </g>
          </g>
        </g>
      </g>
    </g>
  </svg>
)

const hamburgerIcon =
  <svg width='768' height='768' viewBox='0 0 768 768'><path d='M96 160h576q13.3 0 22.6 9.4t9.4 22.6-9.4 22.6-22.6 9.4h-576q-13.2 0-22.6-9.4t-9.4-22.6 9.4-22.6 22.6-9.4zM96 544h576q13.3 0 22.6 9.4t9.4 22.6-9.4 22.6-22.6 9.4h-576q-13.2 0-22.6-9.4t-9.4-22.6 9.4-22.6 22.6-9.4zM96 352h576q13.3 0 22.6 9.4t9.4 22.6-9.4 22.6-22.6 9.4h-576q-13.2 0-22.6-9.4t-9.4-22.6 9.4-22.6 22.6-9.4z' /></svg>

const rocketIcon =
  <svg style={{height: '21px'}} width='24' height='24' fill='#7fc857' viewBox='0 0 24 24'><path d='M22 2c-0.3-0.3-0.8-0.5-1.5-0.5 -1.5 0-4.3 0.7-6.2 2.6L10.3 8.1H3.6c-0.3 0-0.5 0.1-0.7 0.3L2.2 9.1c-0.4 0.4-0.4 1 0 1.4l11.3 11.3c0.2 0.2 0.5 0.3 0.7 0.3s0.5-0.1 0.7-0.3l0.7-0.7c0.2-0.2 0.3-0.4 0.3-0.7l0-6.7 4-3.9c1.4-1.4 2.1-3.3 2.3-4.3C22.4 4.7 22.8 2.8 22 2zM8.3 10.1l-1.8 1.8 -1.8-1.8H8.3zM7.9 13.3l7.1-7.1 2.8 2.8 -7.1 7.1L7.9 13.3zM13.9 19.4l-1.8-1.8 1.8-1.8V19.4zM19.1 7.6l-2.7-2.7c1.4-1 3.1-1.4 4-1.4 0 0 0 0 0 0C20.5 4.3 20.1 6.1 19.1 7.6zM7.9 19c-0.4 0.4-2.2 0.8-3.9 1 0.2-1.7 0.6-3.4 1-3.9 0.3-0.3 0.6-0.4 0.9-0.5l-1.5-1.5c-0.3 0.2-0.6 0.4-0.8 0.6 -1.4 1.4-1.7 5.5-1.7 6.3L1.9 22.2l1.1-0.1c0.8 0 4.9-0.3 6.3-1.7 0.2-0.2 0.4-0.5 0.6-0.8l-1.5-1.5C8.3 18.4 8.1 18.7 7.9 19z' /></svg>

module.exports = {
  contactIcon,
  searchIcon,
  downloadIcon,
  hamburgerIcon,
  rocketIcon
}

==> mongodb-ui-components-4.2.1.tgz: package/src/nav/js/nav-icons.js <==
import React from 'react'

export const contactIcon =
  <svg width='18px' height='18px' viewBox='0 0 32 32' fill='#9E9E9E'><path d='M2.13 1.19c1.28-1.28 5.14-1.49 5.17-0.82 0.03 0.68 3.48 8.19 3.51 8.87s-2.27 2.99-2.95 3.66c-0.67 0.67 4.51 6.53 4.61 6.64 0.11 0.1 5.96 5.29 6.63 4.62 0.67-0.68 2.98-2.98 3.65-2.95 0.68 0.03 8.17 3.49 8.85 3.52 0.68 0.03 0.46 3.9-0.81 5.18-1.09 1.1-6.75 5.07-16.59-2.03-1.08-0.62-2.79-2.05-5.38-4.65 0 0 0 0 0 0 0 0 0 0-0.01-0.01s0 0-0.01-0.01c0 0 0 0 0 0-2.59-2.6-4.01-4.31-4.63-5.39-7.08-9.86-3.12-15.54-2.02-16.63z' /></svg>

export const searchIcon =
  <svg width='21px' height='21px' viewBox='0 0 24 24' fill='#9E9E9E'><path d='M21.7 20.3l-4.5-4.5c1.1-1.4 1.8-3.3 1.8-5.3 0-4.7-3.8-8.5-8.5-8.5s-8.5 3.8-8.5 8.5c0 4.7 3.8 8.5 8.5 8.5 2 0 3.8-0.7 5.3-1.8l4.5 4.5c0.2 0.2 0.5 0.3 0.7 0.3s0.5-0.1 0.7-0.3c0.4-0.4 0.4-1 0-1.4zM4 10.5c0-3.6 2.9-6.5 6.5-6.5s6.5 2.9 6.5 6.5c0 1.8-0.7 3.4-1.9 4.6 0 0 0 0 0 0s0 0 0 0c-1.2 1.2-2.8 1.9-4.6 1.9-3.6 0-6.5-2.9-6.5-6.5z' /></svg>

export const downloadIcon = (
  <svg width='14px' height='21px' viewBox='0 0 16 21'>
    <g stroke='none' strokeWidth='1' fill='none' fillRule='evenodd'>
      <g transform='translate(-1282.000000, -16.000000)' fill='#FFFFFF'>
        <g transform='translate(0.000000, -1.000000)'>
          <g transform='translate(85.000000, 0.000000)'>
            <g transform='translate(1197.000000, 17.000000)'>
              <path d='M13.9079108,6.9539554 L13.0386664,6.9539554 L13.0386664,8.69244425 L13.9079108,8.69244425 L13.9079108,13.9079108 L1.73848885,13.9079108 L1.73848885,8.69244425 L2.60773328,8.69244425 L2.60773328,6.9539554 L1.73848885,6.9539554 C0.77971225,6.9539554 0,7.73366765 0,8.69244425 L0,16.5156441 C0,17.4744207 0.77971225,18.2541329 1.73848885,18.2541329 L6.9539554,18.2541329 L6.9539554,19.1233774 L4.34622213,19.1233774 L4.34622213,20.8618662 L11.3001775,20.8618662 L11.3001775,19.1233774 L8.69244425,19.1233774 L8.69244425,18.2541329 L13.9079108,18.2541329 C14.8666874,18.2541329 15.6463997,17.4744207 15.6463997,16.5156441 L15.6463997,8.69244425 C15.6463997,7.73366765 14.8666874,6.9539554 13.9079108,6.9539554 L13.9079108,6.9539554 Z' />
              <path d='M11.9147333,6.69926679 L10.6856217,5.47015517 L8.69244425,7.46333264 L8.69244425,0 L6.9539554,0 L6.9539554,7.46333264 L4.96077794,5.47015517 L3.73166632,6.69926679 L7.82319983,10.7908003 L11.9147333,6.69926679 Z' id='Shape' />
            </g>
          </g>
        </g>
      </g>
    </g>
  </svg>
)

export const hamburgerIcon =
  <svg width='768' height='768' viewBox='0 0 768 768'><path d='M96 160h576q13.3 0 22.6 9.4t9.4 22.6-9.4 22.6-22.6 9.4h-576q-13.2 0-22.6-9.4t-9.4-22.6 9.4-22.6 22.6-9.4zM96 544h576q13.3 0 22.6 9.4t9.4 22.6-9.4 22.6-22.6 9.4h-576q-13.2 0-22.6-9.4t-9.4-22.6 9.4-22.6 22.6-9.4zM96 352h576q13.3 0 22.6 9.4t9.4 22.6-9.4 22.6-22.6 9.4h-576q-13.2 0-22.6-9.4t-9.4-22.6 9.4-22.6 22.6-9.4z' /></svg>

export const rocketIcon =
  <svg style={{height: '21px'}} width='24' height='24' fill='#7fc857' viewBox='0 0 24 24'><path d='M22 2c-0.3-0.3-0.8-0.5-1.5-0.5 -1.5 0-4.3 0.7-6.2 2.6L10.3 8.1H3.6c-0.3 0-0.5 0.1-0.7 0.3L2.2 9.1c-0.4 0.4-0.4 1 0 1.4l11.3 11.3c0.2 0.2 0.5 0.3 0.7 0.3s0.5-0.1 0.7-0.3l0.7-0.7c0.2-0.2 0.3-0.4 0.3-0.7l0-6.7 4-3.9c1.4-1.4 2.1-3.3 2.3-4.3C22.4 4.7 22.8 2.8 22 2zM8.3 10.1l-1.8 1.8 -1.8-1.8H8.3zM7.9 13.3l7.1-7.1 2.8 2.8 -7.1 7.1L7.9 13.3zM13.9 19.4l-1.8-1.8 1.8-1.8V19.4zM19.1 7.6l-2.7-2.7c1.4-1 3.1-1.4 4-1.4 0 0 0 0 0 0C20.5 4.3 20.1 6.1 19.1 7.6zM7.9 19c-0.4 0.4-2.2 0.8-3.9 1 0.2-1.7 0.6-3.4 1-3.9 0.3-0.3 0.6-0.4 0.9-0.5l-1.5-1.5c-0.3 0.2-0.6 0.4-0.8 0.6 -1.4 1.4-1.7 5.5-1.7 6.3L1.9 22.2l1.1-0.1c0.8 0 4.9-0.3 6.3-1.7 0.2-0.2 0.4-0.5 0.6-0.8l-1.5-1.5C8.3 18.4 8.1 18.7 7.9 19z' /></svg>
